diff --git a/.idea/.gitignore b/.idea/.gitignore
index 13566b8..a9d7db9 100644
--- a/.idea/.gitignore
+++ b/.idea/.gitignore
@@ -6,3 +6,5 @@
# Datasource local storage ignored files
/dataSources/
/dataSources.local.xml
+# GitHub Copilot persisted chat sessions
+/copilot/chatSessions
diff --git a/.idea/codeception.xml b/.idea/codeception.xml
index 11b4cca..42a91a8 100644
--- a/.idea/codeception.xml
+++ b/.idea/codeception.xml
@@ -27,6 +27,12 @@
+
+
+
+
+
+
diff --git a/.idea/php.xml b/.idea/php.xml
index 00dff52..28c9edd 100644
--- a/.idea/php.xml
+++ b/.idea/php.xml
@@ -65,9 +65,11 @@
+
+
-
+
diff --git a/.idea/phpspec.xml b/.idea/phpspec.xml
index b11fb30..8b8e568 100644
--- a/.idea/phpspec.xml
+++ b/.idea/phpspec.xml
@@ -26,6 +26,12 @@
+
+
+
+
+
+
\ No newline at end of file
diff --git a/.idea/tokens-validation.iml b/.idea/tokens-validation.iml
index 843df93..594875c 100644
--- a/.idea/tokens-validation.iml
+++ b/.idea/tokens-validation.iml
@@ -58,6 +58,8 @@
+
+
diff --git a/composer.json b/composer.json
index 3e66311..64a6ca7 100644
--- a/composer.json
+++ b/composer.json
@@ -15,7 +15,7 @@
}
},
"require": {
- "php": ">=8.0",
+ "php": ">=7.1",
"illuminate/database": "^10",
"illuminate/events": "^10",
"illuminate/container": "^10",
diff --git a/composer.lock b/composer.lock
index 12699de..3630e09 100644
--- a/composer.lock
+++ b/composer.lock
@@ -4,29 +4,29 @@
"Read more about it at https://getcomposer.org/doc/01-basic-usage.md#installing-dependencies",
"This file is @generated automatically"
],
- "content-hash": "e7e0f3bdacbb06e95a5f78d54c7969f7",
+ "content-hash": "66a251ec49284f4e4df9a78c890f382b",
"packages": [
{
"name": "brick/math",
- "version": "0.11.0",
+ "version": "0.12.1",
"source": {
"type": "git",
"url": "https://github.com/brick/math.git",
- "reference": "0ad82ce168c82ba30d1c01ec86116ab52f589478"
+ "reference": "f510c0a40911935b77b86859eb5223d58d660df1"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/brick/math/zipball/0ad82ce168c82ba30d1c01ec86116ab52f589478",
- "reference": "0ad82ce168c82ba30d1c01ec86116ab52f589478",
+ "url": "https://api.github.com/repos/brick/math/zipball/f510c0a40911935b77b86859eb5223d58d660df1",
+ "reference": "f510c0a40911935b77b86859eb5223d58d660df1",
"shasum": ""
},
"require": {
- "php": "^8.0"
+ "php": "^8.1"
},
"require-dev": {
"php-coveralls/php-coveralls": "^2.2",
- "phpunit/phpunit": "^9.0",
- "vimeo/psalm": "5.0.0"
+ "phpunit/phpunit": "^10.1",
+ "vimeo/psalm": "5.16.0"
},
"type": "library",
"autoload": {
@@ -46,12 +46,17 @@
"arithmetic",
"bigdecimal",
"bignum",
+ "bignumber",
"brick",
- "math"
+ "decimal",
+ "integer",
+ "math",
+ "mathematics",
+ "rational"
],
"support": {
"issues": "https://github.com/brick/math/issues",
- "source": "https://github.com/brick/math/tree/0.11.0"
+ "source": "https://github.com/brick/math/tree/0.12.1"
},
"funding": [
{
@@ -59,7 +64,76 @@
"type": "github"
}
],
- "time": "2023-01-15T23:15:59+00:00"
+ "time": "2023-11-29T23:19:16+00:00"
+ },
+ {
+ "name": "carbonphp/carbon-doctrine-types",
+ "version": "2.1.0",
+ "source": {
+ "type": "git",
+ "url": "https://github.com/CarbonPHP/carbon-doctrine-types.git",
+ "reference": "99f76ffa36cce3b70a4a6abce41dba15ca2e84cb"
+ },
+ "dist": {
+ "type": "zip",
+ "url": "https://api.github.com/repos/CarbonPHP/carbon-doctrine-types/zipball/99f76ffa36cce3b70a4a6abce41dba15ca2e84cb",
+ "reference": "99f76ffa36cce3b70a4a6abce41dba15ca2e84cb",
+ "shasum": ""
+ },
+ "require": {
+ "php": "^7.4 || ^8.0"
+ },
+ "conflict": {
+ "doctrine/dbal": "<3.7.0 || >=4.0.0"
+ },
+ "require-dev": {
+ "doctrine/dbal": "^3.7.0",
+ "nesbot/carbon": "^2.71.0 || ^3.0.0",
+ "phpunit/phpunit": "^10.3"
+ },
+ "type": "library",
+ "autoload": {
+ "psr-4": {
+ "Carbon\\Doctrine\\": "src/Carbon/Doctrine/"
+ }
+ },
+ "notification-url": "https://packagist.org/downloads/",
+ "license": [
+ "MIT"
+ ],
+ "authors": [
+ {
+ "name": "KyleKatarn",
+ "email": "kylekatarnls@gmail.com"
+ }
+ ],
+ "description": "Types to use Carbon in Doctrine",
+ "keywords": [
+ "carbon",
+ "date",
+ "datetime",
+ "doctrine",
+ "time"
+ ],
+ "support": {
+ "issues": "https://github.com/CarbonPHP/carbon-doctrine-types/issues",
+ "source": "https://github.com/CarbonPHP/carbon-doctrine-types/tree/2.1.0"
+ },
+ "funding": [
+ {
+ "url": "https://github.com/kylekatarnls",
+ "type": "github"
+ },
+ {
+ "url": "https://opencollective.com/Carbon",
+ "type": "open_collective"
+ },
+ {
+ "url": "https://tidelift.com/funding/github/packagist/nesbot/carbon",
+ "type": "tidelift"
+ }
+ ],
+ "time": "2023-12-11T17:09:12+00:00"
},
{
"name": "defuse/php-encryption",
@@ -130,16 +204,16 @@
},
{
"name": "doctrine/inflector",
- "version": "2.0.8",
+ "version": "2.0.10",
"source": {
"type": "git",
"url": "https://github.com/doctrine/inflector.git",
- "reference": "f9301a5b2fb1216b2b08f02ba04dc45423db6bff"
+ "reference": "5817d0659c5b50c9b950feb9af7b9668e2c436bc"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/doctrine/inflector/zipball/f9301a5b2fb1216b2b08f02ba04dc45423db6bff",
- "reference": "f9301a5b2fb1216b2b08f02ba04dc45423db6bff",
+ "url": "https://api.github.com/repos/doctrine/inflector/zipball/5817d0659c5b50c9b950feb9af7b9668e2c436bc",
+ "reference": "5817d0659c5b50c9b950feb9af7b9668e2c436bc",
"shasum": ""
},
"require": {
@@ -201,7 +275,7 @@
],
"support": {
"issues": "https://github.com/doctrine/inflector/issues",
- "source": "https://github.com/doctrine/inflector/tree/2.0.8"
+ "source": "https://github.com/doctrine/inflector/tree/2.0.10"
},
"funding": [
{
@@ -217,25 +291,25 @@
"type": "tidelift"
}
],
- "time": "2023-06-16T13:40:37+00:00"
+ "time": "2024-02-18T20:23:39+00:00"
},
{
"name": "fruitcake/php-cors",
- "version": "v1.2.0",
+ "version": "v1.3.0",
"source": {
"type": "git",
"url": "https://github.com/fruitcake/php-cors.git",
- "reference": "58571acbaa5f9f462c9c77e911700ac66f446d4e"
+ "reference": "3d158f36e7875e2f040f37bc0573956240a5a38b"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/fruitcake/php-cors/zipball/58571acbaa5f9f462c9c77e911700ac66f446d4e",
- "reference": "58571acbaa5f9f462c9c77e911700ac66f446d4e",
+ "url": "https://api.github.com/repos/fruitcake/php-cors/zipball/3d158f36e7875e2f040f37bc0573956240a5a38b",
+ "reference": "3d158f36e7875e2f040f37bc0573956240a5a38b",
"shasum": ""
},
"require": {
"php": "^7.4|^8.0",
- "symfony/http-foundation": "^4.4|^5.4|^6"
+ "symfony/http-foundation": "^4.4|^5.4|^6|^7"
},
"require-dev": {
"phpstan/phpstan": "^1.4",
@@ -245,7 +319,7 @@
"type": "library",
"extra": {
"branch-alias": {
- "dev-main": "1.1-dev"
+ "dev-master": "1.2-dev"
}
},
"autoload": {
@@ -276,7 +350,7 @@
],
"support": {
"issues": "https://github.com/fruitcake/php-cors/issues",
- "source": "https://github.com/fruitcake/php-cors/tree/v1.2.0"
+ "source": "https://github.com/fruitcake/php-cors/tree/v1.3.0"
},
"funding": [
{
@@ -288,34 +362,36 @@
"type": "github"
}
],
- "time": "2022-02-20T15:07:15+00:00"
+ "time": "2023-10-12T05:21:21+00:00"
},
{
"name": "guzzlehttp/uri-template",
- "version": "v1.0.1",
+ "version": "v1.0.3",
"source": {
"type": "git",
"url": "https://github.com/guzzle/uri-template.git",
- "reference": "b945d74a55a25a949158444f09ec0d3c120d69e2"
+ "reference": "ecea8feef63bd4fef1f037ecb288386999ecc11c"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/guzzle/uri-template/zipball/b945d74a55a25a949158444f09ec0d3c120d69e2",
- "reference": "b945d74a55a25a949158444f09ec0d3c120d69e2",
+ "url": "https://api.github.com/repos/guzzle/uri-template/zipball/ecea8feef63bd4fef1f037ecb288386999ecc11c",
+ "reference": "ecea8feef63bd4fef1f037ecb288386999ecc11c",
"shasum": ""
},
"require": {
"php": "^7.2.5 || ^8.0",
- "symfony/polyfill-php80": "^1.17"
+ "symfony/polyfill-php80": "^1.24"
},
"require-dev": {
- "phpunit/phpunit": "^8.5.19 || ^9.5.8",
+ "bamarni/composer-bin-plugin": "^1.8.2",
+ "phpunit/phpunit": "^8.5.36 || ^9.6.15",
"uri-template/tests": "1.0.0"
},
"type": "library",
"extra": {
- "branch-alias": {
- "dev-master": "1.0-dev"
+ "bamarni-bin": {
+ "bin-links": true,
+ "forward-command": false
}
},
"autoload": {
@@ -356,7 +432,7 @@
],
"support": {
"issues": "https://github.com/guzzle/uri-template/issues",
- "source": "https://github.com/guzzle/uri-template/tree/v1.0.1"
+ "source": "https://github.com/guzzle/uri-template/tree/v1.0.3"
},
"funding": [
{
@@ -372,20 +448,20 @@
"type": "tidelift"
}
],
- "time": "2021-10-07T12:57:01+00:00"
+ "time": "2023-12-03T19:50:20+00:00"
},
{
"name": "illuminate/bus",
- "version": "v10.18.0",
+ "version": "v10.48.4",
"source": {
"type": "git",
"url": "https://github.com/illuminate/bus.git",
- "reference": "ec2250684df1ff5cddc4ae639ec913996a4bd0be"
+ "reference": "33993b8f54e91b03fb5000e55693e146e7370763"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/illuminate/bus/zipball/ec2250684df1ff5cddc4ae639ec913996a4bd0be",
- "reference": "ec2250684df1ff5cddc4ae639ec913996a4bd0be",
+ "url": "https://api.github.com/repos/illuminate/bus/zipball/33993b8f54e91b03fb5000e55693e146e7370763",
+ "reference": "33993b8f54e91b03fb5000e55693e146e7370763",
"shasum": ""
},
"require": {
@@ -425,20 +501,20 @@
"issues": "https://github.com/laravel/framework/issues",
"source": "https://github.com/laravel/framework"
},
- "time": "2023-05-22T13:32:28+00:00"
+ "time": "2024-02-23T15:38:25+00:00"
},
{
"name": "illuminate/collections",
- "version": "v10.18.0",
+ "version": "v10.48.4",
"source": {
"type": "git",
"url": "https://github.com/illuminate/collections.git",
- "reference": "66ff5aab0dd10659aff0efe3ff101819db192dfe"
+ "reference": "f9589f1063a449111dcaa1d68285b507d9483a95"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/illuminate/collections/zipball/66ff5aab0dd10659aff0efe3ff101819db192dfe",
- "reference": "66ff5aab0dd10659aff0efe3ff101819db192dfe",
+ "url": "https://api.github.com/repos/illuminate/collections/zipball/f9589f1063a449111dcaa1d68285b507d9483a95",
+ "reference": "f9589f1063a449111dcaa1d68285b507d9483a95",
"shasum": ""
},
"require": {
@@ -480,11 +556,11 @@
"issues": "https://github.com/laravel/framework/issues",
"source": "https://github.com/laravel/framework"
},
- "time": "2023-08-02T14:57:32+00:00"
+ "time": "2024-03-20T20:09:13+00:00"
},
{
"name": "illuminate/conditionable",
- "version": "v10.18.0",
+ "version": "v10.48.4",
"source": {
"type": "git",
"url": "https://github.com/illuminate/conditionable.git",
@@ -530,16 +606,16 @@
},
{
"name": "illuminate/console",
- "version": "v10.18.0",
+ "version": "v10.48.4",
"source": {
"type": "git",
"url": "https://github.com/illuminate/console.git",
- "reference": "0ca6682dc51835e0d0ba2ed953ebb59fe6ff9876"
+ "reference": "f6f9b944ef0f59dd331350bdd1e720c850946bb1"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/illuminate/console/zipball/0ca6682dc51835e0d0ba2ed953ebb59fe6ff9876",
- "reference": "0ca6682dc51835e0d0ba2ed953ebb59fe6ff9876",
+ "url": "https://api.github.com/repos/illuminate/console/zipball/f6f9b944ef0f59dd331350bdd1e720c850946bb1",
+ "reference": "f6f9b944ef0f59dd331350bdd1e720c850946bb1",
"shasum": ""
},
"require": {
@@ -549,7 +625,7 @@
"illuminate/macroable": "^10.0",
"illuminate/support": "^10.0",
"illuminate/view": "^10.0",
- "laravel/prompts": "^0.1",
+ "laravel/prompts": "^0.1.9",
"nunomaduro/termwind": "^1.13",
"php": "^8.1",
"symfony/console": "^6.2",
@@ -591,11 +667,11 @@
"issues": "https://github.com/laravel/framework/issues",
"source": "https://github.com/laravel/framework"
},
- "time": "2023-08-08T14:26:22+00:00"
+ "time": "2024-03-11T21:46:09+00:00"
},
{
"name": "illuminate/container",
- "version": "v10.18.0",
+ "version": "v10.48.4",
"source": {
"type": "git",
"url": "https://github.com/illuminate/container.git",
@@ -646,16 +722,16 @@
},
{
"name": "illuminate/contracts",
- "version": "v10.18.0",
+ "version": "v10.48.4",
"source": {
"type": "git",
"url": "https://github.com/illuminate/contracts.git",
- "reference": "eb1a7e72e159136a832f2c0467de5570bdc208ae"
+ "reference": "8d7152c4a1f5d9cf7da3e8b71f23e4556f6138ac"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/illuminate/contracts/zipball/eb1a7e72e159136a832f2c0467de5570bdc208ae",
- "reference": "eb1a7e72e159136a832f2c0467de5570bdc208ae",
+ "url": "https://api.github.com/repos/illuminate/contracts/zipball/8d7152c4a1f5d9cf7da3e8b71f23e4556f6138ac",
+ "reference": "8d7152c4a1f5d9cf7da3e8b71f23e4556f6138ac",
"shasum": ""
},
"require": {
@@ -690,24 +766,24 @@
"issues": "https://github.com/laravel/framework/issues",
"source": "https://github.com/laravel/framework"
},
- "time": "2023-07-26T21:27:34+00:00"
+ "time": "2024-01-15T18:52:32+00:00"
},
{
"name": "illuminate/database",
- "version": "v10.18.0",
+ "version": "v10.48.4",
"source": {
"type": "git",
"url": "https://github.com/illuminate/database.git",
- "reference": "a52129be2133f83298204770b6110631a1ee13a9"
+ "reference": "0f003d7970b966d3bccf407876fe83cac35ebe67"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/illuminate/database/zipball/a52129be2133f83298204770b6110631a1ee13a9",
- "reference": "a52129be2133f83298204770b6110631a1ee13a9",
+ "url": "https://api.github.com/repos/illuminate/database/zipball/0f003d7970b966d3bccf407876fe83cac35ebe67",
+ "reference": "0f003d7970b966d3bccf407876fe83cac35ebe67",
"shasum": ""
},
"require": {
- "brick/math": "^0.9.3|^0.10.2|^0.11",
+ "brick/math": "^0.9.3|^0.10.2|^0.11|^0.12",
"ext-pdo": "*",
"illuminate/collections": "^10.0",
"illuminate/container": "^10.0",
@@ -716,6 +792,10 @@
"illuminate/support": "^10.0",
"php": "^8.1"
},
+ "conflict": {
+ "carbonphp/carbon-doctrine-types": ">=3.0",
+ "doctrine/dbal": ">=4.0"
+ },
"suggest": {
"doctrine/dbal": "Required to rename columns and drop SQLite columns (^3.5.1).",
"ext-filter": "Required to use the Postgres database driver.",
@@ -759,20 +839,20 @@
"issues": "https://github.com/laravel/framework/issues",
"source": "https://github.com/laravel/framework"
},
- "time": "2023-08-08T14:15:49+00:00"
+ "time": "2024-03-12T02:39:22+00:00"
},
{
"name": "illuminate/events",
- "version": "v10.18.0",
+ "version": "v10.48.4",
"source": {
"type": "git",
"url": "https://github.com/illuminate/events.git",
- "reference": "84bafe2c432b22d21c3fb30be42fe2ae9b2f8fd8"
+ "reference": "a931bfa88edc6ac52c9abbfd7b769343d321d3eb"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/illuminate/events/zipball/84bafe2c432b22d21c3fb30be42fe2ae9b2f8fd8",
- "reference": "84bafe2c432b22d21c3fb30be42fe2ae9b2f8fd8",
+ "url": "https://api.github.com/repos/illuminate/events/zipball/a931bfa88edc6ac52c9abbfd7b769343d321d3eb",
+ "reference": "a931bfa88edc6ac52c9abbfd7b769343d321d3eb",
"shasum": ""
},
"require": {
@@ -814,20 +894,20 @@
"issues": "https://github.com/laravel/framework/issues",
"source": "https://github.com/laravel/framework"
},
- "time": "2023-06-27T14:35:49+00:00"
+ "time": "2024-03-04T14:41:04+00:00"
},
{
"name": "illuminate/filesystem",
- "version": "v10.18.0",
+ "version": "v10.48.4",
"source": {
"type": "git",
"url": "https://github.com/illuminate/filesystem.git",
- "reference": "733b728f11d7ef7a5d673943f0a32a2ffaf6e576"
+ "reference": "592fb581a52fba43bf78c2e4b22db540c9f9f149"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/illuminate/filesystem/zipball/733b728f11d7ef7a5d673943f0a32a2ffaf6e576",
- "reference": "733b728f11d7ef7a5d673943f0a32a2ffaf6e576",
+ "url": "https://api.github.com/repos/illuminate/filesystem/zipball/592fb581a52fba43bf78c2e4b22db540c9f9f149",
+ "reference": "592fb581a52fba43bf78c2e4b22db540c9f9f149",
"shasum": ""
},
"require": {
@@ -858,6 +938,9 @@
}
},
"autoload": {
+ "files": [
+ "functions.php"
+ ],
"psr-4": {
"Illuminate\\Filesystem\\": ""
}
@@ -878,20 +961,20 @@
"issues": "https://github.com/laravel/framework/issues",
"source": "https://github.com/laravel/framework"
},
- "time": "2023-07-24T15:21:36+00:00"
+ "time": "2024-03-11T21:45:53+00:00"
},
{
"name": "illuminate/http",
- "version": "v10.18.0",
+ "version": "v10.48.4",
"source": {
"type": "git",
"url": "https://github.com/illuminate/http.git",
- "reference": "e884a44ed33dc6fd0f9ad1257fc3f4ca055f4649"
+ "reference": "0dd2ee794017c7f5e811cf8fb0dc74c646918d30"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/illuminate/http/zipball/e884a44ed33dc6fd0f9ad1257fc3f4ca055f4649",
- "reference": "e884a44ed33dc6fd0f9ad1257fc3f4ca055f4649",
+ "url": "https://api.github.com/repos/illuminate/http/zipball/0dd2ee794017c7f5e811cf8fb0dc74c646918d30",
+ "reference": "0dd2ee794017c7f5e811cf8fb0dc74c646918d30",
"shasum": ""
},
"require": {
@@ -903,7 +986,7 @@
"illuminate/session": "^10.0",
"illuminate/support": "^10.0",
"php": "^8.1",
- "symfony/http-foundation": "^6.2",
+ "symfony/http-foundation": "^6.4",
"symfony/http-kernel": "^6.2",
"symfony/mime": "^6.2"
},
@@ -938,11 +1021,11 @@
"issues": "https://github.com/laravel/framework/issues",
"source": "https://github.com/laravel/framework"
},
- "time": "2023-08-02T14:11:43+00:00"
+ "time": "2024-02-21T15:19:17+00:00"
},
{
"name": "illuminate/macroable",
- "version": "v10.18.0",
+ "version": "v10.48.4",
"source": {
"type": "git",
"url": "https://github.com/illuminate/macroable.git",
@@ -988,16 +1071,16 @@
},
{
"name": "illuminate/pipeline",
- "version": "v10.18.0",
+ "version": "v10.48.4",
"source": {
"type": "git",
"url": "https://github.com/illuminate/pipeline.git",
- "reference": "f2119ae9a26e420bf0ed9d5e7e7aa4548547e7b1"
+ "reference": "f802187e917a171332cc90f8c1a102939c57405d"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/illuminate/pipeline/zipball/f2119ae9a26e420bf0ed9d5e7e7aa4548547e7b1",
- "reference": "f2119ae9a26e420bf0ed9d5e7e7aa4548547e7b1",
+ "url": "https://api.github.com/repos/illuminate/pipeline/zipball/f802187e917a171332cc90f8c1a102939c57405d",
+ "reference": "f802187e917a171332cc90f8c1a102939c57405d",
"shasum": ""
},
"require": {
@@ -1032,20 +1115,20 @@
"issues": "https://github.com/laravel/framework/issues",
"source": "https://github.com/laravel/framework"
},
- "time": "2023-03-03T15:55:44+00:00"
+ "time": "2023-12-19T14:47:26+00:00"
},
{
"name": "illuminate/session",
- "version": "v10.18.0",
+ "version": "v10.48.4",
"source": {
"type": "git",
"url": "https://github.com/illuminate/session.git",
- "reference": "f39be6b679781d5a7089c76965ed635491b4b5dd"
+ "reference": "a095707b83327e27ba292c9c4d2413888b1f517c"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/illuminate/session/zipball/f39be6b679781d5a7089c76965ed635491b4b5dd",
- "reference": "f39be6b679781d5a7089c76965ed635491b4b5dd",
+ "url": "https://api.github.com/repos/illuminate/session/zipball/a095707b83327e27ba292c9c4d2413888b1f517c",
+ "reference": "a095707b83327e27ba292c9c4d2413888b1f517c",
"shasum": ""
},
"require": {
@@ -1057,7 +1140,7 @@
"illuminate/support": "^10.0",
"php": "^8.1",
"symfony/finder": "^6.2",
- "symfony/http-foundation": "^6.2"
+ "symfony/http-foundation": "^6.4"
},
"suggest": {
"illuminate/console": "Required to use the session:table command (^10.0)."
@@ -1089,20 +1172,20 @@
"issues": "https://github.com/laravel/framework/issues",
"source": "https://github.com/laravel/framework"
},
- "time": "2023-05-09T13:08:05+00:00"
+ "time": "2023-12-29T21:53:12+00:00"
},
{
"name": "illuminate/support",
- "version": "v10.18.0",
+ "version": "v10.48.4",
"source": {
"type": "git",
"url": "https://github.com/illuminate/support.git",
- "reference": "9ce4a26975a919ec33ed21307633ac02208537a8"
+ "reference": "980d80017e859c8b1720892d952516e8c0b6708f"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/illuminate/support/zipball/9ce4a26975a919ec33ed21307633ac02208537a8",
- "reference": "9ce4a26975a919ec33ed21307633ac02208537a8",
+ "url": "https://api.github.com/repos/illuminate/support/zipball/980d80017e859c8b1720892d952516e8c0b6708f",
+ "reference": "980d80017e859c8b1720892d952516e8c0b6708f",
"shasum": ""
},
"require": {
@@ -1160,20 +1243,20 @@
"issues": "https://github.com/laravel/framework/issues",
"source": "https://github.com/laravel/framework"
},
- "time": "2023-08-08T14:14:45+00:00"
+ "time": "2024-03-11T21:46:45+00:00"
},
{
"name": "illuminate/view",
- "version": "v10.18.0",
+ "version": "v10.48.4",
"source": {
"type": "git",
"url": "https://github.com/illuminate/view.git",
- "reference": "dc8e10246d562aa371e2a3a793a1b23735ebf5e3"
+ "reference": "504d55e0f2d90c75588627e6a77a4d1228cf1a02"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/illuminate/view/zipball/dc8e10246d562aa371e2a3a793a1b23735ebf5e3",
- "reference": "dc8e10246d562aa371e2a3a793a1b23735ebf5e3",
+ "url": "https://api.github.com/repos/illuminate/view/zipball/504d55e0f2d90c75588627e6a77a4d1228cf1a02",
+ "reference": "504d55e0f2d90c75588627e6a77a4d1228cf1a02",
"shasum": ""
},
"require": {
@@ -1214,38 +1297,47 @@
"issues": "https://github.com/laravel/framework/issues",
"source": "https://github.com/laravel/framework"
},
- "time": "2023-07-15T20:25:55+00:00"
+ "time": "2024-03-12T16:33:42+00:00"
},
{
"name": "laravel/prompts",
- "version": "v0.1.4",
+ "version": "v0.1.17",
"source": {
"type": "git",
"url": "https://github.com/laravel/prompts.git",
- "reference": "1b3ab520a75eddefcda99f49fb551d231769b1fa"
+ "reference": "8ee9f87f7f9eadcbe21e9e72cd4176b2f06cd5b5"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/laravel/prompts/zipball/1b3ab520a75eddefcda99f49fb551d231769b1fa",
- "reference": "1b3ab520a75eddefcda99f49fb551d231769b1fa",
+ "url": "https://api.github.com/repos/laravel/prompts/zipball/8ee9f87f7f9eadcbe21e9e72cd4176b2f06cd5b5",
+ "reference": "8ee9f87f7f9eadcbe21e9e72cd4176b2f06cd5b5",
"shasum": ""
},
"require": {
"ext-mbstring": "*",
"illuminate/collections": "^10.0|^11.0",
"php": "^8.1",
- "symfony/console": "^6.2"
+ "symfony/console": "^6.2|^7.0"
+ },
+ "conflict": {
+ "illuminate/console": ">=10.17.0 <10.25.0",
+ "laravel/framework": ">=10.17.0 <10.25.0"
},
"require-dev": {
"mockery/mockery": "^1.5",
"pestphp/pest": "^2.3",
- "phpstan/phpstan": "^1.10",
+ "phpstan/phpstan": "^1.11",
"phpstan/phpstan-mockery": "^1.1"
},
"suggest": {
"ext-pcntl": "Required for the spinner to be animated."
},
"type": "library",
+ "extra": {
+ "branch-alias": {
+ "dev-main": "0.1.x-dev"
+ }
+ },
"autoload": {
"files": [
"src/helpers.php"
@@ -1260,34 +1352,39 @@
],
"support": {
"issues": "https://github.com/laravel/prompts/issues",
- "source": "https://github.com/laravel/prompts/tree/v0.1.4"
+ "source": "https://github.com/laravel/prompts/tree/v0.1.17"
},
- "time": "2023-08-07T13:14:59+00:00"
+ "time": "2024-03-13T16:05:43+00:00"
},
{
"name": "nesbot/carbon",
- "version": "2.68.1",
+ "version": "2.72.3",
"source": {
"type": "git",
"url": "https://github.com/briannesbitt/Carbon.git",
- "reference": "4f991ed2a403c85efbc4f23eb4030063fdbe01da"
+ "reference": "0c6fd108360c562f6e4fd1dedb8233b423e91c83"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/briannesbitt/Carbon/zipball/4f991ed2a403c85efbc4f23eb4030063fdbe01da",
- "reference": "4f991ed2a403c85efbc4f23eb4030063fdbe01da",
+ "url": "https://api.github.com/repos/briannesbitt/Carbon/zipball/0c6fd108360c562f6e4fd1dedb8233b423e91c83",
+ "reference": "0c6fd108360c562f6e4fd1dedb8233b423e91c83",
"shasum": ""
},
"require": {
+ "carbonphp/carbon-doctrine-types": "*",
"ext-json": "*",
"php": "^7.1.8 || ^8.0",
+ "psr/clock": "^1.0",
"symfony/polyfill-mbstring": "^1.0",
"symfony/polyfill-php80": "^1.16",
"symfony/translation": "^3.4 || ^4.0 || ^5.0 || ^6.0"
},
+ "provide": {
+ "psr/clock-implementation": "1.0"
+ },
"require-dev": {
- "doctrine/dbal": "^2.0 || ^3.1.4",
- "doctrine/orm": "^2.7",
+ "doctrine/dbal": "^2.0 || ^3.1.4 || ^4.0",
+ "doctrine/orm": "^2.7 || ^3.0",
"friendsofphp/php-cs-fixer": "^3.0",
"kylekatarnls/multi-tester": "^2.0",
"ondrejmirtes/better-reflection": "*",
@@ -1364,7 +1461,7 @@
"type": "tidelift"
}
],
- "time": "2023-06-20T18:29:04+00:00"
+ "time": "2024-01-25T10:35:09+00:00"
},
{
"name": "nunomaduro/termwind",
@@ -1502,6 +1599,54 @@
},
"time": "2020-10-15T08:29:30+00:00"
},
+ {
+ "name": "psr/clock",
+ "version": "1.0.0",
+ "source": {
+ "type": "git",
+ "url": "https://github.com/php-fig/clock.git",
+ "reference": "e41a24703d4560fd0acb709162f73b8adfc3aa0d"
+ },
+ "dist": {
+ "type": "zip",
+ "url": "https://api.github.com/repos/php-fig/clock/zipball/e41a24703d4560fd0acb709162f73b8adfc3aa0d",
+ "reference": "e41a24703d4560fd0acb709162f73b8adfc3aa0d",
+ "shasum": ""
+ },
+ "require": {
+ "php": "^7.0 || ^8.0"
+ },
+ "type": "library",
+ "autoload": {
+ "psr-4": {
+ "Psr\\Clock\\": "src/"
+ }
+ },
+ "notification-url": "https://packagist.org/downloads/",
+ "license": [
+ "MIT"
+ ],
+ "authors": [
+ {
+ "name": "PHP-FIG",
+ "homepage": "https://www.php-fig.org/"
+ }
+ ],
+ "description": "Common interface for reading the clock.",
+ "homepage": "https://github.com/php-fig/clock",
+ "keywords": [
+ "clock",
+ "now",
+ "psr",
+ "psr-20",
+ "time"
+ ],
+ "support": {
+ "issues": "https://github.com/php-fig/clock/issues",
+ "source": "https://github.com/php-fig/clock/tree/1.0.0"
+ },
+ "time": "2022-11-25T14:36:26+00:00"
+ },
{
"name": "psr/container",
"version": "2.0.2",
@@ -1708,16 +1853,16 @@
},
{
"name": "symfony/console",
- "version": "v6.3.2",
+ "version": "v6.4.4",
"source": {
"type": "git",
"url": "https://github.com/symfony/console.git",
- "reference": "aa5d64ad3f63f2e48964fc81ee45cb318a723898"
+ "reference": "0d9e4eb5ad413075624378f474c4167ea202de78"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/symfony/console/zipball/aa5d64ad3f63f2e48964fc81ee45cb318a723898",
- "reference": "aa5d64ad3f63f2e48964fc81ee45cb318a723898",
+ "url": "https://api.github.com/repos/symfony/console/zipball/0d9e4eb5ad413075624378f474c4167ea202de78",
+ "reference": "0d9e4eb5ad413075624378f474c4167ea202de78",
"shasum": ""
},
"require": {
@@ -1725,7 +1870,7 @@
"symfony/deprecation-contracts": "^2.5|^3",
"symfony/polyfill-mbstring": "~1.0",
"symfony/service-contracts": "^2.5|^3",
- "symfony/string": "^5.4|^6.0"
+ "symfony/string": "^5.4|^6.0|^7.0"
},
"conflict": {
"symfony/dependency-injection": "<5.4",
@@ -1739,12 +1884,16 @@
},
"require-dev": {
"psr/log": "^1|^2|^3",
- "symfony/config": "^5.4|^6.0",
- "symfony/dependency-injection": "^5.4|^6.0",
- "symfony/event-dispatcher": "^5.4|^6.0",
- "symfony/lock": "^5.4|^6.0",
- "symfony/process": "^5.4|^6.0",
- "symfony/var-dumper": "^5.4|^6.0"
+ "symfony/config": "^5.4|^6.0|^7.0",
+ "symfony/dependency-injection": "^5.4|^6.0|^7.0",
+ "symfony/event-dispatcher": "^5.4|^6.0|^7.0",
+ "symfony/http-foundation": "^6.4|^7.0",
+ "symfony/http-kernel": "^6.4|^7.0",
+ "symfony/lock": "^5.4|^6.0|^7.0",
+ "symfony/messenger": "^5.4|^6.0|^7.0",
+ "symfony/process": "^5.4|^6.0|^7.0",
+ "symfony/stopwatch": "^5.4|^6.0|^7.0",
+ "symfony/var-dumper": "^5.4|^6.0|^7.0"
},
"type": "library",
"autoload": {
@@ -1778,7 +1927,7 @@
"terminal"
],
"support": {
- "source": "https://github.com/symfony/console/tree/v6.3.2"
+ "source": "https://github.com/symfony/console/tree/v6.4.4"
},
"funding": [
{
@@ -1794,11 +1943,11 @@
"type": "tidelift"
}
],
- "time": "2023-07-19T20:17:28+00:00"
+ "time": "2024-02-22T20:27:10+00:00"
},
{
"name": "symfony/deprecation-contracts",
- "version": "v3.3.0",
+ "version": "v3.4.0",
"source": {
"type": "git",
"url": "https://github.com/symfony/deprecation-contracts.git",
@@ -1845,7 +1994,7 @@
"description": "A generic function and convention to trigger deprecation notices",
"homepage": "https://symfony.com",
"support": {
- "source": "https://github.com/symfony/deprecation-contracts/tree/v3.3.0"
+ "source": "https://github.com/symfony/deprecation-contracts/tree/v3.4.0"
},
"funding": [
{
@@ -1865,30 +2014,31 @@
},
{
"name": "symfony/error-handler",
- "version": "v6.3.2",
+ "version": "v7.0.4",
"source": {
"type": "git",
"url": "https://github.com/symfony/error-handler.git",
- "reference": "85fd65ed295c4078367c784e8a5a6cee30348b7a"
+ "reference": "677b24759decff69e65b1e9d1471d90f95ced880"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/symfony/error-handler/zipball/85fd65ed295c4078367c784e8a5a6cee30348b7a",
- "reference": "85fd65ed295c4078367c784e8a5a6cee30348b7a",
+ "url": "https://api.github.com/repos/symfony/error-handler/zipball/677b24759decff69e65b1e9d1471d90f95ced880",
+ "reference": "677b24759decff69e65b1e9d1471d90f95ced880",
"shasum": ""
},
"require": {
- "php": ">=8.1",
+ "php": ">=8.2",
"psr/log": "^1|^2|^3",
- "symfony/var-dumper": "^5.4|^6.0"
+ "symfony/var-dumper": "^6.4|^7.0"
},
"conflict": {
- "symfony/deprecation-contracts": "<2.5"
+ "symfony/deprecation-contracts": "<2.5",
+ "symfony/http-kernel": "<6.4"
},
"require-dev": {
"symfony/deprecation-contracts": "^2.5|^3",
- "symfony/http-kernel": "^5.4|^6.0",
- "symfony/serializer": "^5.4|^6.0"
+ "symfony/http-kernel": "^6.4|^7.0",
+ "symfony/serializer": "^6.4|^7.0"
},
"bin": [
"Resources/bin/patch-type-declarations"
@@ -1919,7 +2069,7 @@
"description": "Provides tools to manage errors and ease debugging PHP code",
"homepage": "https://symfony.com",
"support": {
- "source": "https://github.com/symfony/error-handler/tree/v6.3.2"
+ "source": "https://github.com/symfony/error-handler/tree/v7.0.4"
},
"funding": [
{
@@ -1935,28 +2085,28 @@
"type": "tidelift"
}
],
- "time": "2023-07-16T17:05:46+00:00"
+ "time": "2024-02-22T20:27:20+00:00"
},
{
"name": "symfony/event-dispatcher",
- "version": "v6.3.2",
+ "version": "v7.0.3",
"source": {
"type": "git",
"url": "https://github.com/symfony/event-dispatcher.git",
- "reference": "adb01fe097a4ee930db9258a3cc906b5beb5cf2e"
+ "reference": "834c28d533dd0636f910909d01b9ff45cc094b5e"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/symfony/event-dispatcher/zipball/adb01fe097a4ee930db9258a3cc906b5beb5cf2e",
- "reference": "adb01fe097a4ee930db9258a3cc906b5beb5cf2e",
+ "url": "https://api.github.com/repos/symfony/event-dispatcher/zipball/834c28d533dd0636f910909d01b9ff45cc094b5e",
+ "reference": "834c28d533dd0636f910909d01b9ff45cc094b5e",
"shasum": ""
},
"require": {
- "php": ">=8.1",
+ "php": ">=8.2",
"symfony/event-dispatcher-contracts": "^2.5|^3"
},
"conflict": {
- "symfony/dependency-injection": "<5.4",
+ "symfony/dependency-injection": "<6.4",
"symfony/service-contracts": "<2.5"
},
"provide": {
@@ -1965,13 +2115,13 @@
},
"require-dev": {
"psr/log": "^1|^2|^3",
- "symfony/config": "^5.4|^6.0",
- "symfony/dependency-injection": "^5.4|^6.0",
- "symfony/error-handler": "^5.4|^6.0",
- "symfony/expression-language": "^5.4|^6.0",
- "symfony/http-foundation": "^5.4|^6.0",
+ "symfony/config": "^6.4|^7.0",
+ "symfony/dependency-injection": "^6.4|^7.0",
+ "symfony/error-handler": "^6.4|^7.0",
+ "symfony/expression-language": "^6.4|^7.0",
+ "symfony/http-foundation": "^6.4|^7.0",
"symfony/service-contracts": "^2.5|^3",
- "symfony/stopwatch": "^5.4|^6.0"
+ "symfony/stopwatch": "^6.4|^7.0"
},
"type": "library",
"autoload": {
@@ -1999,7 +2149,7 @@
"description": "Provides tools that allow your application components to communicate with each other by dispatching events and listening to them",
"homepage": "https://symfony.com",
"support": {
- "source": "https://github.com/symfony/event-dispatcher/tree/v6.3.2"
+ "source": "https://github.com/symfony/event-dispatcher/tree/v7.0.3"
},
"funding": [
{
@@ -2015,11 +2165,11 @@
"type": "tidelift"
}
],
- "time": "2023-07-06T06:56:43+00:00"
+ "time": "2024-01-23T15:02:46+00:00"
},
{
"name": "symfony/event-dispatcher-contracts",
- "version": "v3.3.0",
+ "version": "v3.4.0",
"source": {
"type": "git",
"url": "https://github.com/symfony/event-dispatcher-contracts.git",
@@ -2075,7 +2225,7 @@
"standards"
],
"support": {
- "source": "https://github.com/symfony/event-dispatcher-contracts/tree/v3.3.0"
+ "source": "https://github.com/symfony/event-dispatcher-contracts/tree/v3.4.0"
},
"funding": [
{
@@ -2095,23 +2245,23 @@
},
{
"name": "symfony/finder",
- "version": "v6.3.3",
+ "version": "v6.4.0",
"source": {
"type": "git",
"url": "https://github.com/symfony/finder.git",
- "reference": "9915db259f67d21eefee768c1abcf1cc61b1fc9e"
+ "reference": "11d736e97f116ac375a81f96e662911a34cd50ce"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/symfony/finder/zipball/9915db259f67d21eefee768c1abcf1cc61b1fc9e",
- "reference": "9915db259f67d21eefee768c1abcf1cc61b1fc9e",
+ "url": "https://api.github.com/repos/symfony/finder/zipball/11d736e97f116ac375a81f96e662911a34cd50ce",
+ "reference": "11d736e97f116ac375a81f96e662911a34cd50ce",
"shasum": ""
},
"require": {
"php": ">=8.1"
},
"require-dev": {
- "symfony/filesystem": "^6.0"
+ "symfony/filesystem": "^6.0|^7.0"
},
"type": "library",
"autoload": {
@@ -2139,7 +2289,7 @@
"description": "Finds files and directories via an intuitive fluent interface",
"homepage": "https://symfony.com",
"support": {
- "source": "https://github.com/symfony/finder/tree/v6.3.3"
+ "source": "https://github.com/symfony/finder/tree/v6.4.0"
},
"funding": [
{
@@ -2155,20 +2305,20 @@
"type": "tidelift"
}
],
- "time": "2023-07-31T08:31:44+00:00"
+ "time": "2023-10-31T17:30:12+00:00"
},
{
"name": "symfony/http-foundation",
- "version": "v6.3.2",
+ "version": "v6.4.4",
"source": {
"type": "git",
"url": "https://github.com/symfony/http-foundation.git",
- "reference": "43ed99d30f5f466ffa00bdac3f5f7aa9cd7617c3"
+ "reference": "ebc713bc6e6f4b53f46539fc158be85dfcd77304"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/symfony/http-foundation/zipball/43ed99d30f5f466ffa00bdac3f5f7aa9cd7617c3",
- "reference": "43ed99d30f5f466ffa00bdac3f5f7aa9cd7617c3",
+ "url": "https://api.github.com/repos/symfony/http-foundation/zipball/ebc713bc6e6f4b53f46539fc158be85dfcd77304",
+ "reference": "ebc713bc6e6f4b53f46539fc158be85dfcd77304",
"shasum": ""
},
"require": {
@@ -2178,17 +2328,17 @@
"symfony/polyfill-php83": "^1.27"
},
"conflict": {
- "symfony/cache": "<6.2"
+ "symfony/cache": "<6.3"
},
"require-dev": {
- "doctrine/dbal": "^2.13.1|^3.0",
+ "doctrine/dbal": "^2.13.1|^3|^4",
"predis/predis": "^1.1|^2.0",
- "symfony/cache": "^5.4|^6.0",
- "symfony/dependency-injection": "^5.4|^6.0",
- "symfony/expression-language": "^5.4|^6.0",
- "symfony/http-kernel": "^5.4.12|^6.0.12|^6.1.4",
- "symfony/mime": "^5.4|^6.0",
- "symfony/rate-limiter": "^5.2|^6.0"
+ "symfony/cache": "^6.3|^7.0",
+ "symfony/dependency-injection": "^5.4|^6.0|^7.0",
+ "symfony/expression-language": "^5.4|^6.0|^7.0",
+ "symfony/http-kernel": "^5.4.12|^6.0.12|^6.1.4|^7.0",
+ "symfony/mime": "^5.4|^6.0|^7.0",
+ "symfony/rate-limiter": "^5.4|^6.0|^7.0"
},
"type": "library",
"autoload": {
@@ -2216,7 +2366,7 @@
"description": "Defines an object-oriented layer for the HTTP specification",
"homepage": "https://symfony.com",
"support": {
- "source": "https://github.com/symfony/http-foundation/tree/v6.3.2"
+ "source": "https://github.com/symfony/http-foundation/tree/v6.4.4"
},
"funding": [
{
@@ -2232,29 +2382,29 @@
"type": "tidelift"
}
],
- "time": "2023-07-23T21:58:39+00:00"
+ "time": "2024-02-08T15:01:18+00:00"
},
{
"name": "symfony/http-kernel",
- "version": "v6.3.3",
+ "version": "v6.4.5",
"source": {
"type": "git",
"url": "https://github.com/symfony/http-kernel.git",
- "reference": "d3b567f0addf695e10b0c6d57564a9bea2e058ee"
+ "reference": "f6947cb939d8efee137797382cb4db1af653ef75"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/symfony/http-kernel/zipball/d3b567f0addf695e10b0c6d57564a9bea2e058ee",
- "reference": "d3b567f0addf695e10b0c6d57564a9bea2e058ee",
+ "url": "https://api.github.com/repos/symfony/http-kernel/zipball/f6947cb939d8efee137797382cb4db1af653ef75",
+ "reference": "f6947cb939d8efee137797382cb4db1af653ef75",
"shasum": ""
},
"require": {
"php": ">=8.1",
"psr/log": "^1|^2|^3",
"symfony/deprecation-contracts": "^2.5|^3",
- "symfony/error-handler": "^6.3",
- "symfony/event-dispatcher": "^5.4|^6.0",
- "symfony/http-foundation": "^6.2.7",
+ "symfony/error-handler": "^6.4|^7.0",
+ "symfony/event-dispatcher": "^5.4|^6.0|^7.0",
+ "symfony/http-foundation": "^6.4|^7.0",
"symfony/polyfill-ctype": "^1.8"
},
"conflict": {
@@ -2262,7 +2412,7 @@
"symfony/cache": "<5.4",
"symfony/config": "<6.1",
"symfony/console": "<5.4",
- "symfony/dependency-injection": "<6.3",
+ "symfony/dependency-injection": "<6.4",
"symfony/doctrine-bridge": "<5.4",
"symfony/form": "<5.4",
"symfony/http-client": "<5.4",
@@ -2272,7 +2422,7 @@
"symfony/translation": "<5.4",
"symfony/translation-contracts": "<2.5",
"symfony/twig-bridge": "<5.4",
- "symfony/validator": "<5.4",
+ "symfony/validator": "<6.4",
"symfony/var-dumper": "<6.3",
"twig/twig": "<2.13"
},
@@ -2281,26 +2431,26 @@
},
"require-dev": {
"psr/cache": "^1.0|^2.0|^3.0",
- "symfony/browser-kit": "^5.4|^6.0",
- "symfony/clock": "^6.2",
- "symfony/config": "^6.1",
- "symfony/console": "^5.4|^6.0",
- "symfony/css-selector": "^5.4|^6.0",
- "symfony/dependency-injection": "^6.3",
- "symfony/dom-crawler": "^5.4|^6.0",
- "symfony/expression-language": "^5.4|^6.0",
- "symfony/finder": "^5.4|^6.0",
+ "symfony/browser-kit": "^5.4|^6.0|^7.0",
+ "symfony/clock": "^6.2|^7.0",
+ "symfony/config": "^6.1|^7.0",
+ "symfony/console": "^5.4|^6.0|^7.0",
+ "symfony/css-selector": "^5.4|^6.0|^7.0",
+ "symfony/dependency-injection": "^6.4|^7.0",
+ "symfony/dom-crawler": "^5.4|^6.0|^7.0",
+ "symfony/expression-language": "^5.4|^6.0|^7.0",
+ "symfony/finder": "^5.4|^6.0|^7.0",
"symfony/http-client-contracts": "^2.5|^3",
- "symfony/process": "^5.4|^6.0",
- "symfony/property-access": "^5.4.5|^6.0.5",
- "symfony/routing": "^5.4|^6.0",
- "symfony/serializer": "^6.3",
- "symfony/stopwatch": "^5.4|^6.0",
- "symfony/translation": "^5.4|^6.0",
+ "symfony/process": "^5.4|^6.0|^7.0",
+ "symfony/property-access": "^5.4.5|^6.0.5|^7.0",
+ "symfony/routing": "^5.4|^6.0|^7.0",
+ "symfony/serializer": "^6.4.4|^7.0.4",
+ "symfony/stopwatch": "^5.4|^6.0|^7.0",
+ "symfony/translation": "^5.4|^6.0|^7.0",
"symfony/translation-contracts": "^2.5|^3",
- "symfony/uid": "^5.4|^6.0",
- "symfony/validator": "^6.3",
- "symfony/var-exporter": "^6.2",
+ "symfony/uid": "^5.4|^6.0|^7.0",
+ "symfony/validator": "^6.4|^7.0",
+ "symfony/var-exporter": "^6.2|^7.0",
"twig/twig": "^2.13|^3.0.4"
},
"type": "library",
@@ -2329,7 +2479,7 @@
"description": "Provides a structured process for converting a Request into a Response",
"homepage": "https://symfony.com",
"support": {
- "source": "https://github.com/symfony/http-kernel/tree/v6.3.3"
+ "source": "https://github.com/symfony/http-kernel/tree/v6.4.5"
},
"funding": [
{
@@ -2345,20 +2495,20 @@
"type": "tidelift"
}
],
- "time": "2023-07-31T10:33:00+00:00"
+ "time": "2024-03-04T21:00:47+00:00"
},
{
"name": "symfony/mime",
- "version": "v6.3.3",
+ "version": "v6.4.3",
"source": {
"type": "git",
"url": "https://github.com/symfony/mime.git",
- "reference": "9a0cbd52baa5ba5a5b1f0cacc59466f194730f98"
+ "reference": "5017e0a9398c77090b7694be46f20eb796262a34"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/symfony/mime/zipball/9a0cbd52baa5ba5a5b1f0cacc59466f194730f98",
- "reference": "9a0cbd52baa5ba5a5b1f0cacc59466f194730f98",
+ "url": "https://api.github.com/repos/symfony/mime/zipball/5017e0a9398c77090b7694be46f20eb796262a34",
+ "reference": "5017e0a9398c77090b7694be46f20eb796262a34",
"shasum": ""
},
"require": {
@@ -2372,16 +2522,16 @@
"phpdocumentor/reflection-docblock": "<3.2.2",
"phpdocumentor/type-resolver": "<1.4.0",
"symfony/mailer": "<5.4",
- "symfony/serializer": "<6.2.13|>=6.3,<6.3.2"
+ "symfony/serializer": "<6.3.2"
},
"require-dev": {
"egulias/email-validator": "^2.1.10|^3.1|^4",
"league/html-to-markdown": "^5.0",
"phpdocumentor/reflection-docblock": "^3.0|^4.0|^5.0",
- "symfony/dependency-injection": "^5.4|^6.0",
- "symfony/property-access": "^5.4|^6.0",
- "symfony/property-info": "^5.4|^6.0",
- "symfony/serializer": "~6.2.13|^6.3.2"
+ "symfony/dependency-injection": "^5.4|^6.0|^7.0",
+ "symfony/property-access": "^5.4|^6.0|^7.0",
+ "symfony/property-info": "^5.4|^6.0|^7.0",
+ "symfony/serializer": "^6.3.2|^7.0"
},
"type": "library",
"autoload": {
@@ -2413,7 +2563,7 @@
"mime-type"
],
"support": {
- "source": "https://github.com/symfony/mime/tree/v6.3.3"
+ "source": "https://github.com/symfony/mime/tree/v6.4.3"
},
"funding": [
{
@@ -2429,20 +2579,20 @@
"type": "tidelift"
}
],
- "time": "2023-07-31T07:08:24+00:00"
+ "time": "2024-01-30T08:32:12+00:00"
},
{
"name": "symfony/polyfill-ctype",
- "version": "v1.27.0",
+ "version": "v1.29.0",
"source": {
"type": "git",
"url": "https://github.com/symfony/polyfill-ctype.git",
- "reference": "5bbc823adecdae860bb64756d639ecfec17b050a"
+ "reference": "ef4d7e442ca910c4764bce785146269b30cb5fc4"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/symfony/polyfill-ctype/zipball/5bbc823adecdae860bb64756d639ecfec17b050a",
- "reference": "5bbc823adecdae860bb64756d639ecfec17b050a",
+ "url": "https://api.github.com/repos/symfony/polyfill-ctype/zipball/ef4d7e442ca910c4764bce785146269b30cb5fc4",
+ "reference": "ef4d7e442ca910c4764bce785146269b30cb5fc4",
"shasum": ""
},
"require": {
@@ -2456,9 +2606,6 @@
},
"type": "library",
"extra": {
- "branch-alias": {
- "dev-main": "1.27-dev"
- },
"thanks": {
"name": "symfony/polyfill",
"url": "https://github.com/symfony/polyfill"
@@ -2495,7 +2642,7 @@
"portable"
],
"support": {
- "source": "https://github.com/symfony/polyfill-ctype/tree/v1.27.0"
+ "source": "https://github.com/symfony/polyfill-ctype/tree/v1.29.0"
},
"funding": [
{
@@ -2511,20 +2658,20 @@
"type": "tidelift"
}
],
- "time": "2022-11-03T14:55:06+00:00"
+ "time": "2024-01-29T20:11:03+00:00"
},
{
"name": "symfony/polyfill-intl-grapheme",
- "version": "v1.27.0",
+ "version": "v1.29.0",
"source": {
"type": "git",
"url": "https://github.com/symfony/polyfill-intl-grapheme.git",
- "reference": "511a08c03c1960e08a883f4cffcacd219b758354"
+ "reference": "32a9da87d7b3245e09ac426c83d334ae9f06f80f"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/symfony/polyfill-intl-grapheme/zipball/511a08c03c1960e08a883f4cffcacd219b758354",
- "reference": "511a08c03c1960e08a883f4cffcacd219b758354",
+ "url": "https://api.github.com/repos/symfony/polyfill-intl-grapheme/zipball/32a9da87d7b3245e09ac426c83d334ae9f06f80f",
+ "reference": "32a9da87d7b3245e09ac426c83d334ae9f06f80f",
"shasum": ""
},
"require": {
@@ -2535,9 +2682,6 @@
},
"type": "library",
"extra": {
- "branch-alias": {
- "dev-main": "1.27-dev"
- },
"thanks": {
"name": "symfony/polyfill",
"url": "https://github.com/symfony/polyfill"
@@ -2576,7 +2720,7 @@
"shim"
],
"support": {
- "source": "https://github.com/symfony/polyfill-intl-grapheme/tree/v1.27.0"
+ "source": "https://github.com/symfony/polyfill-intl-grapheme/tree/v1.29.0"
},
"funding": [
{
@@ -2592,20 +2736,20 @@
"type": "tidelift"
}
],
- "time": "2022-11-03T14:55:06+00:00"
+ "time": "2024-01-29T20:11:03+00:00"
},
{
"name": "symfony/polyfill-intl-idn",
- "version": "v1.27.0",
+ "version": "v1.29.0",
"source": {
"type": "git",
"url": "https://github.com/symfony/polyfill-intl-idn.git",
- "reference": "639084e360537a19f9ee352433b84ce831f3d2da"
+ "reference": "a287ed7475f85bf6f61890146edbc932c0fff919"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/symfony/polyfill-intl-idn/zipball/639084e360537a19f9ee352433b84ce831f3d2da",
- "reference": "639084e360537a19f9ee352433b84ce831f3d2da",
+ "url": "https://api.github.com/repos/symfony/polyfill-intl-idn/zipball/a287ed7475f85bf6f61890146edbc932c0fff919",
+ "reference": "a287ed7475f85bf6f61890146edbc932c0fff919",
"shasum": ""
},
"require": {
@@ -2618,9 +2762,6 @@
},
"type": "library",
"extra": {
- "branch-alias": {
- "dev-main": "1.27-dev"
- },
"thanks": {
"name": "symfony/polyfill",
"url": "https://github.com/symfony/polyfill"
@@ -2663,7 +2804,7 @@
"shim"
],
"support": {
- "source": "https://github.com/symfony/polyfill-intl-idn/tree/v1.27.0"
+ "source": "https://github.com/symfony/polyfill-intl-idn/tree/v1.29.0"
},
"funding": [
{
@@ -2679,20 +2820,20 @@
"type": "tidelift"
}
],
- "time": "2022-11-03T14:55:06+00:00"
+ "time": "2024-01-29T20:11:03+00:00"
},
{
"name": "symfony/polyfill-intl-normalizer",
- "version": "v1.27.0",
+ "version": "v1.29.0",
"source": {
"type": "git",
"url": "https://github.com/symfony/polyfill-intl-normalizer.git",
- "reference": "19bd1e4fcd5b91116f14d8533c57831ed00571b6"
+ "reference": "bc45c394692b948b4d383a08d7753968bed9a83d"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/symfony/polyfill-intl-normalizer/zipball/19bd1e4fcd5b91116f14d8533c57831ed00571b6",
- "reference": "19bd1e4fcd5b91116f14d8533c57831ed00571b6",
+ "url": "https://api.github.com/repos/symfony/polyfill-intl-normalizer/zipball/bc45c394692b948b4d383a08d7753968bed9a83d",
+ "reference": "bc45c394692b948b4d383a08d7753968bed9a83d",
"shasum": ""
},
"require": {
@@ -2703,9 +2844,6 @@
},
"type": "library",
"extra": {
- "branch-alias": {
- "dev-main": "1.27-dev"
- },
"thanks": {
"name": "symfony/polyfill",
"url": "https://github.com/symfony/polyfill"
@@ -2747,7 +2885,7 @@
"shim"
],
"support": {
- "source": "https://github.com/symfony/polyfill-intl-normalizer/tree/v1.27.0"
+ "source": "https://github.com/symfony/polyfill-intl-normalizer/tree/v1.29.0"
},
"funding": [
{
@@ -2763,20 +2901,20 @@
"type": "tidelift"
}
],
- "time": "2022-11-03T14:55:06+00:00"
+ "time": "2024-01-29T20:11:03+00:00"
},
{
"name": "symfony/polyfill-mbstring",
- "version": "v1.27.0",
+ "version": "v1.29.0",
"source": {
"type": "git",
"url": "https://github.com/symfony/polyfill-mbstring.git",
- "reference": "8ad114f6b39e2c98a8b0e3bd907732c207c2b534"
+ "reference": "9773676c8a1bb1f8d4340a62efe641cf76eda7ec"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/symfony/polyfill-mbstring/zipball/8ad114f6b39e2c98a8b0e3bd907732c207c2b534",
- "reference": "8ad114f6b39e2c98a8b0e3bd907732c207c2b534",
+ "url": "https://api.github.com/repos/symfony/polyfill-mbstring/zipball/9773676c8a1bb1f8d4340a62efe641cf76eda7ec",
+ "reference": "9773676c8a1bb1f8d4340a62efe641cf76eda7ec",
"shasum": ""
},
"require": {
@@ -2790,9 +2928,6 @@
},
"type": "library",
"extra": {
- "branch-alias": {
- "dev-main": "1.27-dev"
- },
"thanks": {
"name": "symfony/polyfill",
"url": "https://github.com/symfony/polyfill"
@@ -2830,7 +2965,7 @@
"shim"
],
"support": {
- "source": "https://github.com/symfony/polyfill-mbstring/tree/v1.27.0"
+ "source": "https://github.com/symfony/polyfill-mbstring/tree/v1.29.0"
},
"funding": [
{
@@ -2846,20 +2981,20 @@
"type": "tidelift"
}
],
- "time": "2022-11-03T14:55:06+00:00"
+ "time": "2024-01-29T20:11:03+00:00"
},
{
"name": "symfony/polyfill-php72",
- "version": "v1.27.0",
+ "version": "v1.29.0",
"source": {
"type": "git",
"url": "https://github.com/symfony/polyfill-php72.git",
- "reference": "869329b1e9894268a8a61dabb69153029b7a8c97"
+ "reference": "861391a8da9a04cbad2d232ddd9e4893220d6e25"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/symfony/polyfill-php72/zipball/869329b1e9894268a8a61dabb69153029b7a8c97",
- "reference": "869329b1e9894268a8a61dabb69153029b7a8c97",
+ "url": "https://api.github.com/repos/symfony/polyfill-php72/zipball/861391a8da9a04cbad2d232ddd9e4893220d6e25",
+ "reference": "861391a8da9a04cbad2d232ddd9e4893220d6e25",
"shasum": ""
},
"require": {
@@ -2867,9 +3002,6 @@
},
"type": "library",
"extra": {
- "branch-alias": {
- "dev-main": "1.27-dev"
- },
"thanks": {
"name": "symfony/polyfill",
"url": "https://github.com/symfony/polyfill"
@@ -2906,7 +3038,7 @@
"shim"
],
"support": {
- "source": "https://github.com/symfony/polyfill-php72/tree/v1.27.0"
+ "source": "https://github.com/symfony/polyfill-php72/tree/v1.29.0"
},
"funding": [
{
@@ -2922,20 +3054,20 @@
"type": "tidelift"
}
],
- "time": "2022-11-03T14:55:06+00:00"
+ "time": "2024-01-29T20:11:03+00:00"
},
{
"name": "symfony/polyfill-php80",
- "version": "v1.27.0",
+ "version": "v1.29.0",
"source": {
"type": "git",
"url": "https://github.com/symfony/polyfill-php80.git",
- "reference": "7a6ff3f1959bb01aefccb463a0f2cd3d3d2fd936"
+ "reference": "87b68208d5c1188808dd7839ee1e6c8ec3b02f1b"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/symfony/polyfill-php80/zipball/7a6ff3f1959bb01aefccb463a0f2cd3d3d2fd936",
- "reference": "7a6ff3f1959bb01aefccb463a0f2cd3d3d2fd936",
+ "url": "https://api.github.com/repos/symfony/polyfill-php80/zipball/87b68208d5c1188808dd7839ee1e6c8ec3b02f1b",
+ "reference": "87b68208d5c1188808dd7839ee1e6c8ec3b02f1b",
"shasum": ""
},
"require": {
@@ -2943,9 +3075,6 @@
},
"type": "library",
"extra": {
- "branch-alias": {
- "dev-main": "1.27-dev"
- },
"thanks": {
"name": "symfony/polyfill",
"url": "https://github.com/symfony/polyfill"
@@ -2989,7 +3118,7 @@
"shim"
],
"support": {
- "source": "https://github.com/symfony/polyfill-php80/tree/v1.27.0"
+ "source": "https://github.com/symfony/polyfill-php80/tree/v1.29.0"
},
"funding": [
{
@@ -3005,20 +3134,20 @@
"type": "tidelift"
}
],
- "time": "2022-11-03T14:55:06+00:00"
+ "time": "2024-01-29T20:11:03+00:00"
},
{
"name": "symfony/polyfill-php83",
- "version": "v1.27.0",
+ "version": "v1.29.0",
"source": {
"type": "git",
"url": "https://github.com/symfony/polyfill-php83.git",
- "reference": "508c652ba3ccf69f8c97f251534f229791b52a57"
+ "reference": "86fcae159633351e5fd145d1c47de6c528f8caff"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/symfony/polyfill-php83/zipball/508c652ba3ccf69f8c97f251534f229791b52a57",
- "reference": "508c652ba3ccf69f8c97f251534f229791b52a57",
+ "url": "https://api.github.com/repos/symfony/polyfill-php83/zipball/86fcae159633351e5fd145d1c47de6c528f8caff",
+ "reference": "86fcae159633351e5fd145d1c47de6c528f8caff",
"shasum": ""
},
"require": {
@@ -3027,9 +3156,6 @@
},
"type": "library",
"extra": {
- "branch-alias": {
- "dev-main": "1.27-dev"
- },
"thanks": {
"name": "symfony/polyfill",
"url": "https://github.com/symfony/polyfill"
@@ -3041,7 +3167,10 @@
],
"psr-4": {
"Symfony\\Polyfill\\Php83\\": ""
- }
+ },
+ "classmap": [
+ "Resources/stubs"
+ ]
},
"notification-url": "https://packagist.org/downloads/",
"license": [
@@ -3066,7 +3195,7 @@
"shim"
],
"support": {
- "source": "https://github.com/symfony/polyfill-php83/tree/v1.27.0"
+ "source": "https://github.com/symfony/polyfill-php83/tree/v1.29.0"
},
"funding": [
{
@@ -3082,20 +3211,20 @@
"type": "tidelift"
}
],
- "time": "2022-11-03T14:55:06+00:00"
+ "time": "2024-01-29T20:11:03+00:00"
},
{
"name": "symfony/process",
- "version": "v6.3.2",
+ "version": "v6.4.4",
"source": {
"type": "git",
"url": "https://github.com/symfony/process.git",
- "reference": "c5ce962db0d9b6e80247ca5eb9af6472bd4d7b5d"
+ "reference": "710e27879e9be3395de2b98da3f52a946039f297"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/symfony/process/zipball/c5ce962db0d9b6e80247ca5eb9af6472bd4d7b5d",
- "reference": "c5ce962db0d9b6e80247ca5eb9af6472bd4d7b5d",
+ "url": "https://api.github.com/repos/symfony/process/zipball/710e27879e9be3395de2b98da3f52a946039f297",
+ "reference": "710e27879e9be3395de2b98da3f52a946039f297",
"shasum": ""
},
"require": {
@@ -3127,7 +3256,7 @@
"description": "Executes commands in sub-processes",
"homepage": "https://symfony.com",
"support": {
- "source": "https://github.com/symfony/process/tree/v6.3.2"
+ "source": "https://github.com/symfony/process/tree/v6.4.4"
},
"funding": [
{
@@ -3143,25 +3272,25 @@
"type": "tidelift"
}
],
- "time": "2023-07-12T16:00:22+00:00"
+ "time": "2024-02-20T12:31:00+00:00"
},
{
"name": "symfony/service-contracts",
- "version": "v3.3.0",
+ "version": "v3.4.1",
"source": {
"type": "git",
"url": "https://github.com/symfony/service-contracts.git",
- "reference": "40da9cc13ec349d9e4966ce18b5fbcd724ab10a4"
+ "reference": "fe07cbc8d837f60caf7018068e350cc5163681a0"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/symfony/service-contracts/zipball/40da9cc13ec349d9e4966ce18b5fbcd724ab10a4",
- "reference": "40da9cc13ec349d9e4966ce18b5fbcd724ab10a4",
+ "url": "https://api.github.com/repos/symfony/service-contracts/zipball/fe07cbc8d837f60caf7018068e350cc5163681a0",
+ "reference": "fe07cbc8d837f60caf7018068e350cc5163681a0",
"shasum": ""
},
"require": {
"php": ">=8.1",
- "psr/container": "^2.0"
+ "psr/container": "^1.1|^2.0"
},
"conflict": {
"ext-psr": "<1.1|>=2"
@@ -3209,7 +3338,7 @@
"standards"
],
"support": {
- "source": "https://github.com/symfony/service-contracts/tree/v3.3.0"
+ "source": "https://github.com/symfony/service-contracts/tree/v3.4.1"
},
"funding": [
{
@@ -3225,24 +3354,24 @@
"type": "tidelift"
}
],
- "time": "2023-05-23T14:45:45+00:00"
+ "time": "2023-12-26T14:02:43+00:00"
},
{
"name": "symfony/string",
- "version": "v6.3.2",
+ "version": "v7.0.4",
"source": {
"type": "git",
"url": "https://github.com/symfony/string.git",
- "reference": "53d1a83225002635bca3482fcbf963001313fb68"
+ "reference": "f5832521b998b0bec40bee688ad5de98d4cf111b"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/symfony/string/zipball/53d1a83225002635bca3482fcbf963001313fb68",
- "reference": "53d1a83225002635bca3482fcbf963001313fb68",
+ "url": "https://api.github.com/repos/symfony/string/zipball/f5832521b998b0bec40bee688ad5de98d4cf111b",
+ "reference": "f5832521b998b0bec40bee688ad5de98d4cf111b",
"shasum": ""
},
"require": {
- "php": ">=8.1",
+ "php": ">=8.2",
"symfony/polyfill-ctype": "~1.8",
"symfony/polyfill-intl-grapheme": "~1.0",
"symfony/polyfill-intl-normalizer": "~1.0",
@@ -3252,11 +3381,11 @@
"symfony/translation-contracts": "<2.5"
},
"require-dev": {
- "symfony/error-handler": "^5.4|^6.0",
- "symfony/http-client": "^5.4|^6.0",
- "symfony/intl": "^6.2",
+ "symfony/error-handler": "^6.4|^7.0",
+ "symfony/http-client": "^6.4|^7.0",
+ "symfony/intl": "^6.4|^7.0",
"symfony/translation-contracts": "^2.5|^3.0",
- "symfony/var-exporter": "^5.4|^6.0"
+ "symfony/var-exporter": "^6.4|^7.0"
},
"type": "library",
"autoload": {
@@ -3295,7 +3424,7 @@
"utf8"
],
"support": {
- "source": "https://github.com/symfony/string/tree/v6.3.2"
+ "source": "https://github.com/symfony/string/tree/v7.0.4"
},
"funding": [
{
@@ -3311,20 +3440,20 @@
"type": "tidelift"
}
],
- "time": "2023-07-05T08:41:27+00:00"
+ "time": "2024-02-01T13:17:36+00:00"
},
{
"name": "symfony/translation",
- "version": "v6.3.3",
+ "version": "v6.4.4",
"source": {
"type": "git",
"url": "https://github.com/symfony/translation.git",
- "reference": "3ed078c54bc98bbe4414e1e9b2d5e85ed5a5c8bd"
+ "reference": "bce6a5a78e94566641b2594d17e48b0da3184a8e"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/symfony/translation/zipball/3ed078c54bc98bbe4414e1e9b2d5e85ed5a5c8bd",
- "reference": "3ed078c54bc98bbe4414e1e9b2d5e85ed5a5c8bd",
+ "url": "https://api.github.com/repos/symfony/translation/zipball/bce6a5a78e94566641b2594d17e48b0da3184a8e",
+ "reference": "bce6a5a78e94566641b2594d17e48b0da3184a8e",
"shasum": ""
},
"require": {
@@ -3347,19 +3476,19 @@
"symfony/translation-implementation": "2.3|3.0"
},
"require-dev": {
- "nikic/php-parser": "^4.13",
+ "nikic/php-parser": "^4.18|^5.0",
"psr/log": "^1|^2|^3",
- "symfony/config": "^5.4|^6.0",
- "symfony/console": "^5.4|^6.0",
- "symfony/dependency-injection": "^5.4|^6.0",
- "symfony/finder": "^5.4|^6.0",
+ "symfony/config": "^5.4|^6.0|^7.0",
+ "symfony/console": "^5.4|^6.0|^7.0",
+ "symfony/dependency-injection": "^5.4|^6.0|^7.0",
+ "symfony/finder": "^5.4|^6.0|^7.0",
"symfony/http-client-contracts": "^2.5|^3.0",
- "symfony/http-kernel": "^5.4|^6.0",
- "symfony/intl": "^5.4|^6.0",
+ "symfony/http-kernel": "^5.4|^6.0|^7.0",
+ "symfony/intl": "^5.4|^6.0|^7.0",
"symfony/polyfill-intl-icu": "^1.21",
- "symfony/routing": "^5.4|^6.0",
+ "symfony/routing": "^5.4|^6.0|^7.0",
"symfony/service-contracts": "^2.5|^3",
- "symfony/yaml": "^5.4|^6.0"
+ "symfony/yaml": "^5.4|^6.0|^7.0"
},
"type": "library",
"autoload": {
@@ -3390,7 +3519,7 @@
"description": "Provides tools to internationalize your application",
"homepage": "https://symfony.com",
"support": {
- "source": "https://github.com/symfony/translation/tree/v6.3.3"
+ "source": "https://github.com/symfony/translation/tree/v6.4.4"
},
"funding": [
{
@@ -3406,20 +3535,20 @@
"type": "tidelift"
}
],
- "time": "2023-07-31T07:08:24+00:00"
+ "time": "2024-02-20T13:16:58+00:00"
},
{
"name": "symfony/translation-contracts",
- "version": "v3.3.0",
+ "version": "v3.4.1",
"source": {
"type": "git",
"url": "https://github.com/symfony/translation-contracts.git",
- "reference": "02c24deb352fb0d79db5486c0c79905a85e37e86"
+ "reference": "06450585bf65e978026bda220cdebca3f867fde7"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/symfony/translation-contracts/zipball/02c24deb352fb0d79db5486c0c79905a85e37e86",
- "reference": "02c24deb352fb0d79db5486c0c79905a85e37e86",
+ "url": "https://api.github.com/repos/symfony/translation-contracts/zipball/06450585bf65e978026bda220cdebca3f867fde7",
+ "reference": "06450585bf65e978026bda220cdebca3f867fde7",
"shasum": ""
},
"require": {
@@ -3468,7 +3597,7 @@
"standards"
],
"support": {
- "source": "https://github.com/symfony/translation-contracts/tree/v3.3.0"
+ "source": "https://github.com/symfony/translation-contracts/tree/v3.4.1"
},
"funding": [
{
@@ -3484,37 +3613,36 @@
"type": "tidelift"
}
],
- "time": "2023-05-30T17:17:10+00:00"
+ "time": "2023-12-26T14:02:43+00:00"
},
{
"name": "symfony/var-dumper",
- "version": "v6.3.3",
+ "version": "v7.0.4",
"source": {
"type": "git",
"url": "https://github.com/symfony/var-dumper.git",
- "reference": "77fb4f2927f6991a9843633925d111147449ee7a"
+ "reference": "e03ad7c1535e623edbb94c22cc42353e488c6670"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/symfony/var-dumper/zipball/77fb4f2927f6991a9843633925d111147449ee7a",
- "reference": "77fb4f2927f6991a9843633925d111147449ee7a",
+ "url": "https://api.github.com/repos/symfony/var-dumper/zipball/e03ad7c1535e623edbb94c22cc42353e488c6670",
+ "reference": "e03ad7c1535e623edbb94c22cc42353e488c6670",
"shasum": ""
},
"require": {
- "php": ">=8.1",
- "symfony/deprecation-contracts": "^2.5|^3",
+ "php": ">=8.2",
"symfony/polyfill-mbstring": "~1.0"
},
"conflict": {
- "symfony/console": "<5.4"
+ "symfony/console": "<6.4"
},
"require-dev": {
"ext-iconv": "*",
- "symfony/console": "^5.4|^6.0",
- "symfony/http-kernel": "^5.4|^6.0",
- "symfony/process": "^5.4|^6.0",
- "symfony/uid": "^5.4|^6.0",
- "twig/twig": "^2.13|^3.0.4"
+ "symfony/console": "^6.4|^7.0",
+ "symfony/http-kernel": "^6.4|^7.0",
+ "symfony/process": "^6.4|^7.0",
+ "symfony/uid": "^6.4|^7.0",
+ "twig/twig": "^3.0.4"
},
"bin": [
"Resources/bin/var-dump-server"
@@ -3552,7 +3680,7 @@
"dump"
],
"support": {
- "source": "https://github.com/symfony/var-dumper/tree/v6.3.3"
+ "source": "https://github.com/symfony/var-dumper/tree/v7.0.4"
},
"funding": [
{
@@ -3568,7 +3696,7 @@
"type": "tidelift"
}
],
- "time": "2023-07-31T07:08:24+00:00"
+ "time": "2024-02-15T11:33:06+00:00"
},
{
"name": "voku/portable-ascii",
@@ -3652,8 +3780,8 @@
"prefer-stable": false,
"prefer-lowest": false,
"platform": {
- "php": ">=8.0"
+ "php": ">=7.1"
},
"platform-dev": [],
- "plugin-api-version": "2.3.0"
+ "plugin-api-version": "2.6.0"
}
diff --git a/src/Actions/Confirmation/ConfirmationCodeGenerator.php b/src/Actions/Confirmation/ConfirmationCodeGenerator.php
index a2f73ae..2ed3d35 100644
--- a/src/Actions/Confirmation/ConfirmationCodeGenerator.php
+++ b/src/Actions/Confirmation/ConfirmationCodeGenerator.php
@@ -18,10 +18,13 @@ class ConfirmationCodeGenerator
*/
public function generate(int $confirmationType): string
{
- return match ($confirmationType) {
- ConfirmationsTokenTypes::SMALL_CODE => TokensValidation::generateAlphaNumKey(6, true),
- ConfirmationsTokenTypes::IN_URL => TokensValidation::generateAlphaNumKey(15),
- default => "",
- };
+ switch ($confirmationType) {
+ case ConfirmationsTokenTypes::SMALL_CODE:
+ return TokensValidation::generateAlphaNumKey(6, true);
+ case ConfirmationsTokenTypes::IN_URL:
+ return TokensValidation::generateAlphaNumKey(15);
+ default:
+ return "";
+ }
}
}
\ No newline at end of file
diff --git a/src/Actions/Confirmation/UserIdAndToken.php b/src/Actions/Confirmation/UserIdAndToken.php
index 1440b28..8ba7412 100644
--- a/src/Actions/Confirmation/UserIdAndToken.php
+++ b/src/Actions/Confirmation/UserIdAndToken.php
@@ -9,12 +9,12 @@ class UserIdAndToken {
/**
* @var string The user ID.
*/
- private string $userId;
+ private $userId;
/**
* @var string The token.
*/
- private string $token;
+ private $token;
/**
* UserIdAndToken constructor.
diff --git a/src/Actions/Confirmation/UserIdAndTokenBuilder.php b/src/Actions/Confirmation/UserIdAndTokenBuilder.php
index 9ce3603..cef93ca 100644
--- a/src/Actions/Confirmation/UserIdAndTokenBuilder.php
+++ b/src/Actions/Confirmation/UserIdAndTokenBuilder.php
@@ -11,12 +11,12 @@ class UserIdAndTokenBuilder {
/**
* @var string|null The user ID.
*/
- private ?string $userId = null;
+ private $userId = null;
/**
* @var string|null The token.
*/
- private ?string $token = null;
+ private $token = null;
/**
* Sets the user ID.
diff --git a/src/Actions/UserIdEncrypter.php b/src/Actions/UserIdEncrypter.php
index 5726f11..2f1bc6d 100644
--- a/src/Actions/UserIdEncrypter.php
+++ b/src/Actions/UserIdEncrypter.php
@@ -21,7 +21,7 @@ class UserIdEncrypter
*
* @var string
*/
- protected static string $encrypterKey = 'def00000d92d8449abd99476b92ce79555cd81fa28173ed18f0162419b8a7332a00281c2c1e6568d67e3901cfd55fafdd9112d206feebb1d7e8acaf4dc08f0d6ab576a46';
+ protected static $encrypterKey = 'def00000d92d8449abd99476b92ce79555cd81fa28173ed18f0162419b8a7332a00281c2c1e6568d67e3901cfd55fafdd9112d206feebb1d7e8acaf4dc08f0d6ab576a46';
/**
* @param $userId
diff --git a/src/Model/Authentication/AuthToken.php b/src/Model/Authentication/AuthToken.php
index 8f1f32f..9976a3c 100644
--- a/src/Model/Authentication/AuthToken.php
+++ b/src/Model/Authentication/AuthToken.php
@@ -12,28 +12,28 @@ class AuthToken
/**
* @var string $userId
*/
- private string $userId;
+ private $userId;
/**
* @var integer $type
*/
- private int $type;
+ private $type;
/**
* @var string $content
*/
- private string $content;
+ private $content;
/**
* @var DateTime $expiredAt
*/
- private DateTime $expiredAt;
+ private $expiredAt;
/**
* @var string $userAgent
*/
- private string $userAgent;
+ private $userAgent;
/**
* @var string $fingerprint
*/
- private string $fingerprint;
+ private $fingerprint;
/**
* @param $userId
diff --git a/src/Model/Authentication/AuthTokenBuilder.php b/src/Model/Authentication/AuthTokenBuilder.php
index 244315a..7513278 100644
--- a/src/Model/Authentication/AuthTokenBuilder.php
+++ b/src/Model/Authentication/AuthTokenBuilder.php
@@ -12,32 +12,32 @@ class AuthTokenBuilder
/**
* @var string
*/
- private string $userId;
+ private $userId;
/**
* @var int
*/
- private int $type;
+ private $type;
/**
* @var string
*/
- private string $content;
+ private $content;
/**
* @var DateTime
*/
- private DateTime $expiredAt;
+ private $expiredAt;
/**
* @var string
*/
- private string $userAgent;
+ private $userAgent;
/**
* @var string
*/
- private string $fingerprint;
+ private $fingerprint;
/**
* @param string $userId
diff --git a/src/Model/Confirmation/ConfirmationToken.php b/src/Model/Confirmation/ConfirmationToken.php
index 3fff0dc..a53e5de 100644
--- a/src/Model/Confirmation/ConfirmationToken.php
+++ b/src/Model/Confirmation/ConfirmationToken.php
@@ -13,27 +13,27 @@ class ConfirmationToken
/**
* @var string $userId
*/
- private string $userId;
+ private $userId;
/**
* @var int $type
*/
- private int $type;
+ private $type;
/**
* @var string $content
*/
- private string $content;
+ private $content;
/**
* @var DateTime $expiredAt
*/
- private DateTime $expiredAt;
+ private $expiredAt;
/**
* @var string $whatFor
*/
- private string $whatFor;
+ private $whatFor;
/**
* ConfirmationToken constructor.
diff --git a/src/Model/Confirmation/ConfirmationTokenBuilder.php b/src/Model/Confirmation/ConfirmationTokenBuilder.php
index 4a8876c..30d920a 100644
--- a/src/Model/Confirmation/ConfirmationTokenBuilder.php
+++ b/src/Model/Confirmation/ConfirmationTokenBuilder.php
@@ -9,27 +9,27 @@ class ConfirmationTokenBuilder
/**
* @var string|null $userId
*/
- private ?string $userId = null;
+ private $userId = null;
/**
* @var int|null $type
*/
- private ?int $type = null;
+ private $type = null;
/**
* @var string|null $content
*/
- private ?string $content = null;
+ private $content = null;
/**
* @var DateTime|null $expiredAt
*/
- private ?DateTime $expiredAt = null;
+ private $expiredAt = null;
/**
* @var string|null $whatFor
*/
- private ?string $whatFor = null;
+ private $whatFor = null;
/**
* Sets the user ID for the token.
diff --git a/src/Model/Invitation/Invitation.php b/src/Model/Invitation/Invitation.php
index 3d38f42..8dd2e10 100644
--- a/src/Model/Invitation/Invitation.php
+++ b/src/Model/Invitation/Invitation.php
@@ -13,42 +13,42 @@ class Invitation
/**
* @var string|null The unique identifier for the invitation.
*/
- protected ?string $id;
+ protected $id;
/**
* @var string|null The unique identifier for the user who created the invitation.
*/
- protected ?string $userId;
+ protected $userId;
/**
* @var string|null The email address of the user who the invitation is being sent to.
*/
- private ?string $target_email;
+ private $target_email;
/**
* @var string|null The content of the invitation message.
*/
- private ?string $content;
+ private $content;
/**
* @var DateTime|null The date and time when the invitation will expire.
*/
- private ?DateTime $expire_at;
+ private $expire_at;
/**
* @var string|null The purpose of the invitation.
*/
- private ?string $whatFor;
+ private $whatFor;
/**
* @var string|null Additional data related to the invitation.
*/
- private ?string $data;
+ private $data;
/**
* @var bool Whether the invitation has been accepted.
*/
- private bool $accepted;
+ private $accepted;
/**
* Invitation constructor.
diff --git a/src/Model/Invitation/InvitationBuilder.php b/src/Model/Invitation/InvitationBuilder.php
index 1623c6f..082a400 100644
--- a/src/Model/Invitation/InvitationBuilder.php
+++ b/src/Model/Invitation/InvitationBuilder.php
@@ -13,42 +13,42 @@ class InvitationBuilder
/**
* @var string|null $id The invitation ID.
*/
- private ?string $id = null;
+ private $id = null;
/**
* @var string|null $userId The user ID associated with the invitation.
*/
- private ?string $userId;
+ private $userId;
/**
* @var string|null $targetEmail The email address that the invitation is being sent to.
*/
- private ?string $targetEmail = null;
+ private $targetEmail = null;
/**
* @var string|null $content The message content of the invitation.
*/
- private ?string $content = null;
+ private $content = null;
/**
* @var DateTime|null $expireAt The expiration date and time of the invitation.
*/
- private ?DateTime $expireAt = null;
+ private $expireAt = null;
/**
* @var string|null $whatFor The purpose of the invitation.
*/
- private ?string $whatFor = null;
+ private $whatFor = null;
/**
* @var string|null $data Additional data associated with the invitation.
*/
- private ?string $data = null;
+ private $data = null;
/**
* @var bool $accepted Whether the invitation has been accepted or not.
*/
- private bool $accepted = false;
+ private $accepted = false;
/**
* @param string|null $userId
diff --git a/src/Results/Authentication/AuthTokenResponse.php b/src/Results/Authentication/AuthTokenResponse.php
index 90eec1c..1219277 100644
--- a/src/Results/Authentication/AuthTokenResponse.php
+++ b/src/Results/Authentication/AuthTokenResponse.php
@@ -4,6 +4,7 @@
use HichemtabTech\TokensValidation\Model\Authentication\AuthToken;
use HichemtabTech\TokensValidation\Results\BaseResults;
+use HichemtabTech\TokensValidation\Results\BaseResultsBuilder;
/**
* Represents the response of an authentication token request.
@@ -15,14 +16,14 @@ class AuthTokenResponse extends BaseResults
*
* @var string|null
*/
- private ?string $userId;
+ private $userId;
/**
* The new authentication token.
*
* @var AuthToken|null
*/
- private AuthToken|null $newToken;
+ private $newToken;
/**
* Creates a new instance of the AuthTokenResponse class with the specified builder.
@@ -57,9 +58,9 @@ public function getNewToken(): ?AuthToken
}
/**
- * @return AuthTokenResponseBuilder
+ * @return BaseResultsBuilder
*/
- public static function builder(): AuthTokenResponseBuilder
+ public static function builder(): BaseResultsBuilder
{
return new AuthTokenResponseBuilder();
}
diff --git a/src/Results/BaseResults.php b/src/Results/BaseResults.php
index e8cfd05..69ae741 100644
--- a/src/Results/BaseResults.php
+++ b/src/Results/BaseResults.php
@@ -14,22 +14,22 @@ class BaseResults
/**
* @var bool Indicates if the validation process succeeded or not.
*/
- private bool $validationSucceed;
+ private $validationSucceed;
/**
* @var string|null Contains a message explaining why the validation process failed.
*/
- private ?string $cause;
+ private $cause;
/**
* @var string|null Contains the ID of the token that was validated.
*/
- private ?string $tokenId;
+ private $tokenId;
/**
* @var Exception|null Contains an exception explaining why the validation process failed.
*/
- private ?Exception $exception;
+ private $exception;
/**
* BaseResults constructor.
diff --git a/src/Results/BaseResultsBuilder.php b/src/Results/BaseResultsBuilder.php
index f161151..c4c6ac7 100644
--- a/src/Results/BaseResultsBuilder.php
+++ b/src/Results/BaseResultsBuilder.php
@@ -11,10 +11,10 @@
*/
class BaseResultsBuilder
{
- private bool $validationSucceed;
- private ?string $cause;
- private ?string $tokenId;
- private ?Exception $exception;
+ private $validationSucceed;
+ private $cause;
+ private $tokenId;
+ private $exception;
/**
* BaseResultsBuilder constructor.
diff --git a/src/Results/Confirmation/ConfirmationTokenResponse.php b/src/Results/Confirmation/ConfirmationTokenResponse.php
index 84653ff..7a53738 100644
--- a/src/Results/Confirmation/ConfirmationTokenResponse.php
+++ b/src/Results/Confirmation/ConfirmationTokenResponse.php
@@ -3,6 +3,7 @@
namespace HichemtabTech\TokensValidation\Results\Confirmation;
use HichemtabTech\TokensValidation\Results\BaseResults;
+use HichemtabTech\TokensValidation\Results\BaseResultsBuilder;
/**
* Represents a response to a confirmation token request.
@@ -12,11 +13,11 @@ class ConfirmationTokenResponse extends BaseResults
/**
* @var string|null
*/
- private ?string $userId;
+ private $userId;
/**
* @var string|null
*/
- private ?string $whatFor;
+ private $whatFor;
public function __construct(ConfirmationTokenResponseBuilder $builder)
{
@@ -72,9 +73,9 @@ public function setWhatFor(?string $whatFor): ConfirmationTokenResponse
/**
* Creates a new ConfirmationTokenResponse object using the builder pattern.
*
- * @return ConfirmationTokenResponseBuilder The builder object.
+ * @return BaseResultsBuilder The builder object.
*/
- public static function builder(): ConfirmationTokenResponseBuilder
+ public static function builder(): BaseResultsBuilder
{
return new ConfirmationTokenResponseBuilder();
}
diff --git a/src/Results/Confirmation/ConfirmationTokenResponseBuilder.php b/src/Results/Confirmation/ConfirmationTokenResponseBuilder.php
index 5883ad8..ed49663 100644
--- a/src/Results/Confirmation/ConfirmationTokenResponseBuilder.php
+++ b/src/Results/Confirmation/ConfirmationTokenResponseBuilder.php
@@ -2,6 +2,7 @@
namespace HichemtabTech\TokensValidation\Results\Confirmation;
+use HichemtabTech\TokensValidation\Results\BaseResults;
use HichemtabTech\TokensValidation\Results\BaseResultsBuilder;
/**
@@ -12,12 +13,12 @@ class ConfirmationTokenResponseBuilder extends BaseResultsBuilder
/**
* @var string|null
*/
- private ?string $userId;
+ private $userId;
/**
* @var string|null
*/
- private ?string $whatFor;
+ private $whatFor;
public function __construct()
{
@@ -47,9 +48,9 @@ public function withWhatFor(?string $whatFor): self
}
/**
- * @return ConfirmationTokenResponse
+ * @return BaseResults
*/
- public function build(): ConfirmationTokenResponse
+ public function build(): BaseResults
{
return new ConfirmationTokenResponse($this);
}
diff --git a/src/Results/Invitation/InvitationResponse.php b/src/Results/Invitation/InvitationResponse.php
index 05e1b12..0d71b22 100644
--- a/src/Results/Invitation/InvitationResponse.php
+++ b/src/Results/Invitation/InvitationResponse.php
@@ -3,28 +3,29 @@
namespace HichemtabTech\TokensValidation\Results\Invitation;
use HichemtabTech\TokensValidation\Results\BaseResults;
+use HichemtabTech\TokensValidation\Results\BaseResultsBuilder;
class InvitationResponse extends BaseResults
{
/**
* @var string|null
*/
- private ?string $whatFor;
+ private $whatFor;
/**
* @var string|null
*/
- private ?string $userId;
+ private $userId;
/**
* @var string|null
*/
- private ?string $target_email;
+ private $target_email;
/**
* @var string|null
*/
- private ?string $data;
+ private $data;
public function __construct(InvitationResponseBuilder $builder)
{
@@ -78,9 +79,9 @@ public function getData(): ?string
/**
* Creates a new InvitationResponse object using the builder pattern.
*
- * @return InvitationResponseBuilder The builder object.
+ * @return BaseResultsBuilder The builder object.
*/
- public static function builder(): InvitationResponseBuilder
+ public static function builder(): BaseResultsBuilder
{
return new InvitationResponseBuilder();
}
diff --git a/src/Results/Invitation/InvitationResponseBuilder.php b/src/Results/Invitation/InvitationResponseBuilder.php
index b129bfe..baca919 100644
--- a/src/Results/Invitation/InvitationResponseBuilder.php
+++ b/src/Results/Invitation/InvitationResponseBuilder.php
@@ -2,6 +2,7 @@
namespace HichemtabTech\TokensValidation\Results\Invitation;
+use HichemtabTech\TokensValidation\Results\BaseResults;
use HichemtabTech\TokensValidation\Results\BaseResultsBuilder;
/**
@@ -12,22 +13,22 @@ class InvitationResponseBuilder extends BaseResultsBuilder
/**
* @var string|null
*/
- private ?string $whatFor;
+ private $whatFor;
/**
* @var string|null
*/
- private ?string $userId;
+ private $userId;
/**
* @var string|null
*/
- private ?string $target_email;
+ private $target_email;
/**
* @var string|null
*/
- private ?string $data;
+ private $data;
public function __construct()
{
@@ -79,9 +80,9 @@ public function withData(?string $data): self
}
/**
- * @return InvitationResponse
+ * @return BaseResults
*/
- public function build(): InvitationResponse
+ public function build(): BaseResults
{
return new InvitationResponse($this);
}
diff --git a/src/TokensValidation.php b/src/TokensValidation.php
index 79030f5..1d037df 100644
--- a/src/TokensValidation.php
+++ b/src/TokensValidation.php
@@ -1,4 +1,7 @@
-setValidationSucceed(false);
@@ -590,10 +602,10 @@ private static function checkAuthToken_(string $fingerPrint, ?string $authToken,
/**
* @param string $fingerPrint
* @param string|null $authToken
- * @return AuthTokenResponse
+ * @return Results\BaseResults
* @throws Exception
*/
- public static function checkAuthTokenWithoutRegenerate(string $fingerPrint = "", ?string $authToken = null): AuthTokenResponse
+ public static function checkAuthTokenWithoutRegenerate(string $fingerPrint = "", ?string $authToken = null): Results\BaseResults
{
return self::checkAuthToken_($fingerPrint, $authToken, false);
}
@@ -601,10 +613,10 @@ public static function checkAuthTokenWithoutRegenerate(string $fingerPrint = "",
/**
* @param string $fingerPrint
* @param string|null $authToken
- * @return AuthTokenResponse
+ * @return Results\BaseResults
* @throws Exception
*/
- public static function checkAuthToken(string $fingerPrint = "", ?string $authToken = null): AuthTokenResponse
+ public static function checkAuthToken(string $fingerPrint = "", ?string $authToken = null): Results\BaseResults
{
return self::checkAuthToken_($fingerPrint, $authToken, true);
}
@@ -637,9 +649,9 @@ public static function deleteAuthToken(string $tokenId): void
* @param string|null $encryptedUserId
* @param string $whatFor
* @param bool $deleteAfterCheck
- * @return ConfirmationTokenResponse
+ * @return Results\BaseResults
*/
- public static function checkConfirmationCode(string $code, string $encryptedUserId = null, string $whatFor = "default", bool $deleteAfterCheck = true): ConfirmationTokenResponse
+ public static function checkConfirmationCode(string $code, string $encryptedUserId = null, string $whatFor = "default", bool $deleteAfterCheck = true): Results\BaseResults
{
$confirmationTokenResultsBuilder = ConfirmationTokenResponse::builder()
->setValidationSucceed(false);
@@ -692,9 +704,9 @@ public static function checkConfirmationCode(string $code, string $encryptedUser
* @param string $url
* @param string $whatFor
* @param bool $deleteAfterCheck
- * @return ConfirmationTokenResponse
+ * @return Results\BaseResults
*/
- public static function checkConfirmationUrl(string $url, string $whatFor = "default", bool $deleteAfterCheck = true): ConfirmationTokenResponse
+ public static function checkConfirmationUrl(string $url, string $whatFor = "default", bool $deleteAfterCheck = true): Results\BaseResults
{
/** @var UserIdAndToken $userIdAndToken */
$userIdAndToken = call_user_func_array([new TokensValidation::$ConfirmationUrlBuilder(), 'getUserIdAndTokenFromUrl'], [$url]);
@@ -712,9 +724,9 @@ public static function checkConfirmationUrl(string $url, string $whatFor = "defa
* @param array $_GET_ARRAY
* @param string $whatFor
* @param bool $deleteAfterCheck
- * @return ConfirmationTokenResponse
+ * @return Results\BaseResults
*/
- public static function checkConfirmationUrlParamsFromGET(array $_GET_ARRAY, string $whatFor = "default", bool $deleteAfterCheck = true): ConfirmationTokenResponse
+ public static function checkConfirmationUrlParamsFromGET(array $_GET_ARRAY, string $whatFor = "default", bool $deleteAfterCheck = true): Results\BaseResults
{
/** @var UserIdAndToken $userIdAndToken */
$userIdAndToken = call_user_func_array([new TokensValidation::$ConfirmationUrlBuilder(), 'getUserIdAndTokenFromGET'], [$_GET_ARRAY]);
@@ -758,7 +770,11 @@ private static function isExpired(DateTime $expirationDate): bool
*/
private static function regenerateAuthToken($userId, $oldToken, $tokenType): AuthToken
{
- return self::createNewToken(userId: $userId, type: $tokenType, oldToken: $oldToken);
+ return self::createNewToken(
+ $userId,
+ $tokenType,
+ $oldToken
+ );
}
/**
@@ -770,7 +786,7 @@ private static function regenerateAuthToken($userId, $oldToken, $tokenType): Aut
* @return Invitation
* @throws Exception
*/
- public static function createInvitation(string $userId, string $target_email, float|int $expirationDelay = -1, string $whatFor = "default", string $data = ""): Invitation
+ public static function createInvitation(string $userId, string $target_email, $expirationDelay = -1, string $whatFor = "default", string $data = ""): Invitation
{
$datetime = new DateTime();
if ($expirationDelay == -1) {
@@ -810,9 +826,9 @@ public static function createInvitation(string $userId, string $target_email, fl
* @param string $token
* @param string $whatFor
* @param bool $thenAccept
- * @return InvitationResponse
+ * @return Results\BaseResults
*/
- public static function checkInvitationToken(string $token, string $whatFor = "default", bool $thenAccept = false): InvitationResponse
+ public static function checkInvitationToken(string $token, string $whatFor = "default", bool $thenAccept = false): Results\BaseResults
{
$invitationResultsBuilder = InvitationResponse::builder()
->setValidationSucceed(false);
@@ -858,9 +874,9 @@ public static function checkInvitationToken(string $token, string $whatFor = "de
* @param string $url
* @param string $whatFor
* @param bool $thenAccept
- * @return InvitationResponse
+ * @return Results\BaseResults
*/
- public static function checkInvitationUrl(string $url, string $whatFor = "default", bool $thenAccept = false): InvitationResponse
+ public static function checkInvitationUrl(string $url, string $whatFor = "default", bool $thenAccept = false): Results\BaseResults
{
return self::checkInvitationToken(call_user_func_array([new TokensValidation::$InvitationUrlBuilder(), 'getTokenFromUrl'], [$url]), $whatFor, $thenAccept);
}
@@ -869,9 +885,9 @@ public static function checkInvitationUrl(string $url, string $whatFor = "defaul
* @param array $_GET_ARRAY
* @param string $whatFor
* @param bool $thenAccept
- * @return InvitationResponse
+ * @return Results\BaseResults
*/
- public static function checkInvitationUrlParamsFromGET(array $_GET_ARRAY, string $whatFor = "default", bool $thenAccept = false): InvitationResponse
+ public static function checkInvitationUrlParamsFromGET(array $_GET_ARRAY, string $whatFor = "default", bool $thenAccept = false): Results\BaseResults
{
return self::checkInvitationToken(call_user_func_array([new TokensValidation::$InvitationUrlBuilder(), 'getTokenFromGET'], [$_GET_ARRAY]), $whatFor, $thenAccept);
}
@@ -880,9 +896,9 @@ public static function checkInvitationUrlParamsFromGET(array $_GET_ARRAY, string
* @param Request $request
* @param string $whatFor
* @param bool $thenAccept
- * @return InvitationResponse
+ * @return Results\BaseResults
*/
- public static function checkInvitationRequest(Request $request, string $whatFor = "default", bool $thenAccept = false): InvitationResponse
+ public static function checkInvitationRequest(Request $request, string $whatFor = "default", bool $thenAccept = false): Results\BaseResults
{
return self::checkInvitationToken(call_user_func_array([new TokensValidation::$InvitationUrlBuilder(), 'getTokenFromRequest'], [$request]), $whatFor, $thenAccept);
}
diff --git a/src/Results/Authentication/AuthTokenResponseBuilder.php b/src/Results/Authentication/AuthTokenResponseBuilder.php
index aa66ec2..976b58e 100644
--- a/src/Results/Authentication/AuthTokenResponseBuilder.php
+++ b/src/Results/Authentication/AuthTokenResponseBuilder.php
@@ -3,6 +3,7 @@
namespace HichemtabTech\TokensValidation\Results\Authentication;
use HichemtabTech\TokensValidation\Model\Authentication\AuthToken;
+use HichemtabTech\TokensValidation\Results\BaseResults;
use HichemtabTech\TokensValidation\Results\BaseResultsBuilder;
/**
@@ -15,14 +16,14 @@ class AuthTokenResponseBuilder extends BaseResultsBuilder
*
* @var string|null
*/
- private ?string $userId;
+ private $userId;
/**
* The new authentication token.
*
* @var AuthToken|null
*/
- private ?AuthToken $newToken;
+ private $newToken;
public function __construct()
{
@@ -60,9 +61,9 @@ public function setNewToken(?AuthToken $newToken): self
/**
* Builds and returns an instance of the AuthTokenResponse class with the configured settings.
*
* @return AuthTokenResponse The resulting AuthTokenResponse instance.
*/
- public function build(): AuthTokenResponse
+ public function build(): BaseResults
{
return new AuthTokenResponse($this);
}
@@ -60,9 +61,9 @@ public function setNewToken(?AuthToken $newToken): self
* Builds and returns an instance of the AuthTokenResponse class with the configured settings.
*
- * @return AuthTokenResponse The resulting AuthTokenResponse instance.
+ * @return BaseResults The resulting AuthTokenResponse instance.
*/